==> haskell-hackage-db-2.1.3-54-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hackage-db.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hackage-db
version:              2.1.3
visibility:           public
id:                   hackage-db-2.1.3-6cMCwwk2xbQ9bYSUlE92yk
key:                  hackage-db-2.1.3-6cMCwwk2xbQ9bYSUlE92yk
license:              BSD-3-Clause
maintainer:           sternenseemann <sternenseemann@systemli.org>
author:               Peter Simons, Alexander Altman, Ben James, Kevin Quick
homepage:
    https://github.com/NixOS/cabal2nix/tree/master/hackage-db#readme

synopsis:             Access cabal-install'\''s Hackage database via Data.Map
description:
    This library provides convenient access to the local copy of the Hackage
    database that \"cabal update\" creates. Check out
    <https://github.com/NixOS/hackage-db/tree/master/example/> for a collection
    of simple example programs that demonstrate how to use this code.

category:             Distribution
abi:                  567a79d9dd744ae784f50615f054fd7d
exposed:              True
exposed-modules:
    Distribution.Hackage.DB Distribution.Hackage.DB.Builder
    Distribution.Hackage.DB.Errors Distribution.Hackage.DB.MetaData
    Distribution.Hackage.DB.Parsed Distribution.Hackage.DB.Path
    Distribution.Hackage.DB.Unparsed Distribution.Hackage.DB.Utility

hidden-modules:       Paths_hackage_db
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hackage-db-2.1.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hackage-db-2.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hackage-db
hs-libraries:         HShackage-db-2.1.3-6cMCwwk2xbQ9bYSUlE92yk
depends:
    Cabal-3.6.3.0 aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 directory-1.3.6.2
    exceptions-0.10.4 filepath-1.4.2.2
    tar-0.5.1.1-CmQihJxv27rI4SRTxO9RwD time-1.11.1.1
    utf8-string-1.0.2-AQMRv3gsvE14uh4nlO1egX

haddock-interfaces:   /usr/share/doc/haskell-hackage-db/html/hackage-db.haddock
haddock-html:         /usr/share/doc/haskell-hackage-db/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hackage-db-2.1.3-101.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hackage-db.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hackage-db
version:              2.1.3
visibility:           public
id:                   hackage-db-2.1.3-DS2ZKXTllL8DWjI7yH9Dwk
key:                  hackage-db-2.1.3-DS2ZKXTllL8DWjI7yH9Dwk
license:              BSD-3-Clause
maintainer:           sternenseemann <sternenseemann@systemli.org>
author:               Peter Simons, Alexander Altman, Ben James, Kevin Quick
homepage:
    https://github.com/NixOS/cabal2nix/tree/master/hackage-db#readme

synopsis:             Access cabal-install'\''s Hackage database via Data.Map
description:
    This library provides convenient access to the local copy of the Hackage
    database that \"cabal update\" creates. Check out
    <https://github.com/NixOS/hackage-db/tree/master/example/> for a collection
    of simple example programs that demonstrate how to use this code.

category:             Distribution
abi:                  5aa748973f4fe02325ed683fa60c29a9
exposed:              True
exposed-modules:
    Distribution.Hackage.DB Distribution.Hackage.DB.Builder
    Distribution.Hackage.DB.Errors Distribution.Hackage.DB.MetaData
    Distribution.Hackage.DB.Parsed Distribution.Hackage.DB.Path
    Distribution.Hackage.DB.Unparsed Distribution.Hackage.DB.Utility

hidden-modules:       Paths_hackage_db
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hackage-db-2.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hackage-db-2.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hackage-db-2.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hackage-db
hs-libraries:         HShackage-db-2.1.3-DS2ZKXTllL8DWjI7yH9Dwk
depends:
    Cabal-3.8.1.0 aeson-2.1.2.1-38LADbNStwmEfKOReucTQy base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    exceptions-0.10.5 filepath-1.4.2.2
    tar-0.5.1.1-BLuIMuVMMpO3QzRO6EC9PJ time-1.12.2
    utf8-string-1.0.2-FnO1h94XkEn7naEuvLflUO

haddock-interfaces:   /usr/share/doc/haskell-hackage-db/html/hackage-db.haddock
haddock-html:         /usr/share/doc/haskell-hackage-db/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
